summaryrefslogtreecommitdiffstats
path: root/scripts/kDebug2kdDebug.sh
diff options
context:
space:
mode:
authorMichele Calgaro <michele.calgaro@yahoo.it>2023-09-25 20:06:11 +0900
committerMichele Calgaro <michele.calgaro@yahoo.it>2023-09-25 20:33:38 +0900
commit7485c8248a1bb3a2fed851d389a291d60bba7752 (patch)
tree01530186491285c596ad8bea4ee9368436e38a48 /scripts/kDebug2kdDebug.sh
parent2611dd9a2020f335eff619aeeffc3730144ce657 (diff)
downloadtdesdk-7485c8248a1bb3a2fed851d389a291d60bba7752.tar.gz
tdesdk-7485c8248a1bb3a2fed851d389a291d60bba7752.zip
Replace QObject, QWidget, QImage, QPair, QRgb, QColor, QChar, QString, QIODevice with TQ* versionr14.1.1
Signed-off-by: Michele Calgaro <michele.calgaro@yahoo.it> (cherry picked from commit 0ffe839d6e363933ed4d9d212b6fd325a6fc3225)
Diffstat (limited to 'scripts/kDebug2kdDebug.sh')
-rwxr-xr-xscripts/kDebug2kdDebug.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/scripts/kDebug2kdDebug.sh b/scripts/kDebug2kdDebug.sh
index 2a08b610..871bc439 100755
--- a/scripts/kDebug2kdDebug.sh
+++ b/scripts/kDebug2kdDebug.sh
@@ -99,8 +99,8 @@ while (<>)
if ( /(%[0-9]*[a-z])/ ) # This item is a format
{
## 3 - Find argument
- # kludge for QString(a,b) constructions
- $arguments =~ s/(QString\s*\([^,]+,[^,]+\))/QStrKLUDGE/;
+ # kludge for TQString(a,b) constructions
+ $arguments =~ s/(TQString\s*\([^,]+,[^,]+\))/QStrKLUDGE/;
$kludge = $1;
$arguments =~ s/\s*([^,]+)\s*,//;
# Remove trailing .ascii() and latin1()